@@ -31,15 +31,15 @@
 #include <openssl/evp.h>
 #include <openssl/pem.h>
 
-#include <loc/libloc.h>
-#include <loc/as.h>
-#include <loc/compat.h>
-#include <loc/country.h>
-#include <loc/database.h>
-#include <loc/format.h>
-#include <loc/network.h>
-#include <loc/private.h>
-#include <loc/writer.h>
+#include <libloc/libloc.h>
+#include <libloc/as.h>
+#include <libloc/compat.h>
+#include <libloc/country.h>
+#include <libloc/database.h>
+#include <libloc/format.h>
+#include <libloc/network.h>
+#include <libloc/private.h>
+#include <libloc/writer.h>
 
 struct loc_writer {
 	struct loc_ctx* ctx;
@@ -423,6 +423,8 @@ static int loc_database_write_networks(struct loc_writer* writer,
 	// Add root
 	struct loc_network_tree_node* root = loc_network_tree_get_root(writer->networks);
 	node = make_node(root);
+	if (!node)
+		return 1;
 
 	TAILQ_INSERT_TAIL(&nodes, node, nodes);
 
@@ -463,6 +465,10 @@ static int loc_database_write_networks(struct loc_writer* writer,
 
 			// Append network to be written out later
 			struct network* nw = make_network(network);
+			if (!nw) {
+				free_node(node);
+				return 1;
+			}
 			TAILQ_INSERT_TAIL(&networks, nw, networks);
 
 			db_node.network = htobe32(network_index++);
